# [2.4.7](https://github.com/seriaati/enka-py/compare/v2.4.6..v2.4.7) - 2025-03-26

## Bug Fixes

- Fix Trace.type type - ([2c8d273](https://github.com/seriaati/enka-py/commit/2c8d2735f1be68b618618c489d222c3360a91883))

## Miscellaneous Chores

- **(deps)** lock file maintenance ([#93](https://github.com/seriaati/enka-py/issues/93)) - ([bfb04b8](https://github.com/seriaati/enka-py/commit/bfb04b8983737d43b9a705be1e271b5984fc3af4))
- **(deps)** lock file maintenance ([#94](https://github.com/seriaati/enka-py/issues/94)) - ([f90a84f](https://github.com/seriaati/enka-py/commit/f90a84ff63dd12c520d7e044b425c5ff0baa3e14))
- **(deps)** lock file maintenance ([#95](https://github.com/seriaati/enka-py/issues/95)) - ([7ae0800](https://github.com/seriaati/enka-py/commit/7ae0800fd3d404e11c827b0326850624626abc12))
- **(deps)** lock file maintenance ([#97](https://github.com/seriaati/enka-py/issues/97)) - ([c7f37ae](https://github.com/seriaati/enka-py/commit/c7f37ae5a9ee06388925845611e48680e27a9c25))
- Remove vscode folder and add it to gitignore - ([446a893](https://github.com/seriaati/enka-py/commit/446a8939b0fcdb1f25ead942e83614b53062e87f))
- Update ruff config - ([1f5f7f4](https://github.com/seriaati/enka-py/commit/1f5f7f4b4e0b8f748bf71e28972867045dc04051))
- Update pyright configs - ([41a3f8d](https://github.com/seriaati/enka-py/commit/41a3f8dd2068a78442fd16d54b15191905d4e2be))

## Refactoring

- Organize imports - ([79bf33d](https://github.com/seriaati/enka-py/commit/79bf33d0e1fee2809e4ed3f7efea8535d3ceceb2))
- Use pathlib - ([d98c792](https://github.com/seriaati/enka-py/commit/d98c792668b77c9da51e210905b63e39a7d1ddeb))
- Multiple refactors - ([99c5515](https://github.com/seriaati/enka-py/commit/99c55158cdffeab18aa9a0fb60374277482af254))
- Remove unused noqa & add explicit return - ([03c4518](https://github.com/seriaati/enka-py/commit/03c45184c90a15b13174a89c9228e8d2fae9450a))
- Refactor asset handling - ([d2155dd](https://github.com/seriaati/enka-py/commit/d2155dd48bf0339ba0e11b47b3f9ff8fc866b0be))

